==> percona-xtrabackup_8.0.35-30.orig.tar.gz: percona-xtrabackup-8.0.35-30/plugin/group_replication/libmysqlgcs/src/interface/gcs_group_identifier.cc <==
/* Copyright (c) 2014, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include "plugin/group_replication/libmysqlgcs/include/mysql/gcs/gcs_group_identifier.h"

Gcs_group_identifier::Gcs_group_identifier(const std::string &gid)
    : group_id(gid) {}

const std::string &Gcs_group_identifier::get_group_id() const {
  return group_id;
}

/* purecov: begin deadcode */
bool Gcs_group_identifier::operator<(const Gcs_group_identifier &other) const {
  return group_id.compare(other.group_id) < 0;
}

bool Gcs_group_identifier::operator==(const Gcs_group_identifier &other) const {
  return group_id.compare(other.group_id) == 0;
}
/* purecov: end */

==> percona-xtrabackup_8.4.0-1.orig.tar.gz: percona-xtrabackup-8.4.0-1/plugin/group_replication/libmysqlgcs/src/interface/gcs_group_identifier.cc <==
/* Copyright (c) 2014, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include "plugin/group_replication/libmysqlgcs/include/mysql/gcs/gcs_group_identifier.h"

Gcs_group_identifier::Gcs_group_identifier(const std::string &gid)
    : group_id(gid) {}

const std::string &Gcs_group_identifier::get_group_id() const {
  return group_id;
}

/* purecov: begin deadcode */
bool Gcs_group_identifier::operator<(const Gcs_group_identifier &other) const {
  return group_id.compare(other.group_id) < 0;
}

bool Gcs_group_identifier::operator==(const Gcs_group_identifier &other) const {
  return group_id.compare(other.group_id) == 0;
}
/* purecov: end */
